//
//  Arguments.cpp
//  Commandline Argument Handling
//
//  Created by Clemens Wacha.
//  Version 1.1
//  Copyright (c) 2005 Clemens Wacha. All rights reserved.
//

#ifndef _ARGUMENTS_H
#define _ARGUMENTS_H


//	This class makes handling argc, argv (as supplied by main() i.e.) very easy. After initializing you provide
//	it with an option you would like to have and an optional default value. If the option is found inside argv it
//	will be returned to you, if not you get the default value. Reading an option from the argument list removes it 
//  from the argument list. It works like a stack with a find-and-pop function :-)


#include <string>
#include <vector>

class Arguments {

public:
	Arguments();
	Arguments(int argc, char* argv[]);
	Arguments(const std::vector<std::string>&);
	~Arguments();
	
	// returns true if flag is found, false else
	bool getFlag(const std::string& option, const std::string& long_option = "");
	// returns integer if found, supplied default_value else
	int	getInt(const std::string& option, const std::string& default_value = "", const std::string& long_option = "");
	// returns long if found, supplied default_value else
	//long getLong(const std::string& option, const std::string& default_value = "", const std::string& long_option = "");
	// returns float if found, supplied default_value else
	//float getFloat(const std::string& option, const std::string& default_value = "", const std::string& long_option = "");
	// returns double if found, supplied default_value else
	double getDouble(const std::string& option, const std::string& default_value = "", const std::string& long_option = "");
	// returns string if found, supplied default_value else
	std::string getString(const std::string& option, const std::string& default_value = "", const std::string& long_option = "");
	// returns char* to a C string if found, char* to a copy of default_value if not found.
	// Remark that you will have to free() the returned string once you don't need it anymore!
	char* getCString(const std::string& option, const std::string& default_value = "", const std::string& long_option = "");
	
	// return first element
	std::string front();
	// return last element
	std::string back();
	// return number of elements currently in the argument list
	unsigned int size();
	// return comma separated string containing all elements in the argument list
	std::string list();
	
private:
	std::string argument(const std::string& option, const std::string& default_value = "", const std::string& long_option = "");

	std::vector<std::string> arg_list;
};


#endif // _ARGUMENTS_H
